==> vue-comps-waves-0.1.0.tgz: package/waves.js <==
var GradientStore, Velocity;

Velocity = require("velocity-animate");

GradientStore = require('./gradient-store');

module.exports = {
  mixins: [require("vue-mixins/setCss"), require("vue-mixins/getVue")],
  props: {
    color: {
      type: String,
      "default": "black"
    },
    speed: {
      type: Number,
      "default": 1
    }
  },
  watch: {
    color: "processColor"
  },
  data: function() {
    return {
      gradUrl: null,
      ripples: [],
      debug: ""
    };
  },
  methods: {
    processColor: function(val) {
      if (val == null) {
        val = this.color;
      }
      return this.gradUrl = "url(#" + this.getId(this.color) + ")";
    },
    show: function(e) {
      var duration, isTouch, pos, ripple, rippleDiv, rippleEl, size, x, y;
      if (e.pointerType === "mouse") {
        return;
      }
      isTouch = (e.pointerType != null) && e.pointerType !== "mouse";
      if (isTouch) {
        e = e.srcEvent;
      }
      if (e.offsetX) {
        x = e.offsetX;
        y = e.offsetY;
      } else {
        pos = e.target.getBoundingClientRect();
        x = e.x - pos.left;
        y = e.y - pos.top;
      }
      size = Math.max(this.$el.offsetWidth - x, this.$el.offsetHeight - y, x, y) * 3;
      rippleDiv = this.$els.rippleDiv.cloneNode(true);
      this.setCss(rippleDiv, "top", y + "px");
      this.setCss(rippleDiv, "left", x + "px");
      this.$el.appendChild(rippleDiv);
      duration = size / this.speed / 0.35;
      rippleEl = rippleDiv.firstChild;
      Velocity(rippleEl, {
        opacity: 0.5
      }, {
        duration: duration * 1 / 2,
        queue: false
      });
      Velocity(rippleEl, {
        width: size,
        height: size
      }, {
        duration: duration,
        easing: "easeIn",
        queue: false
      });
      if (isTouch) {
        return setTimeout(((function(_this) {
          return function() {
            return _this.hide({
              rippleDiv: rippleDiv,
              duration: duration * 1 / 2
            });
          };
        })(this)), duration * 1 / 2);
      } else {
        ripple = {
          rippleDiv: rippleDiv,
          duration: duration * 1 / 2,
          released: false,
          timeouted: false
        };
        this.ripples.push(ripple);
        return setTimeout(((function(_this) {
          return function() {
            ripple.timeouted = true;
            if (ripple.released) {
              return _this.hide(ripple);
            }
          };
        })(this)), duration * 1 / 2);
      }
    },
    hide: function(ripple) {
      return Velocity(ripple.rippleDiv.firstChild, {
        opacity: 0
      }, {
        duration: ripple.duration,
        complete: (function(_this) {
          return function() {
            ripple.rippleDiv.remove();
            return _this.ripples.splice(_this.ripples.indexOf(ripple), 1);
          };
        })(this)
      });
    },
    release: function() {
      var lastRipple;
      lastRipple = this.ripples[this.ripples.length - 1];
      if (lastRipple != null) {
        lastRipple.released = true;
        if (lastRipple.timeouted) {
          return this.hide(lastRipple);
        }
      }
    }
  },
  compiled: function() {
    this.getId = GradientStore(this.getVue()).getId;
    return this.processColor();
  }
};

if (module.exports.__esModule) module.exports = module.exports.default
;(typeof module.exports === "function"? module.exports.options: module.exports).template = "<div :style=\"{position:'relative',overflow:'hidden',display:'inline-block',touchAction:'auto'}\" v-touch:tap=show @mouseup=release @mousedown=show><div style=position:absolute;pointer-events:none;transform:translate(-50%,-50%);border-radius:50%;line-height:0 v-el:ripple-div=v-el:ripple-div><svg xmlns=http://www.w3.org/2000/svg height=10 width=10 style=position:relative;opacity:0;pointer-events:none><rect x=0 y=0 width=100% height=100% :fill=gradUrl></rect></svg></div><slot></slot></div>"

==> vue-comps-waves-0.1.1.tgz: package/waves.js <==
var GradientStore, Velocity;

Velocity = require("velocity-animate");

GradientStore = require('./gradient-store');

module.exports = {
  mixins: [require("vue-mixins/setCss"), require("vue-mixins/vue")],
  props: {
    color: {
      type: String,
      "default": "black"
    },
    speed: {
      type: Number,
      "default": 1
    }
  },
  computed: {
    gradUrl: function() {
      if (this.getId == null) {
        return null;
      }
      console.log("test");
      return "url(#" + this.getId(this.color) + ")";
    }
  },
  data: function() {
    return {
      getId: null,
      gradUrl: null,
      ripples: [],
      debug: ""
    };
  },
  methods: {
    show: function(e) {
      var duration, isTouch, pos, ripple, rippleDiv, rippleEl, size, x, y;
      if (e.pointerType === "mouse") {
        return;
      }
      isTouch = (e.pointerType != null) && e.pointerType !== "mouse";
      if (isTouch) {
        e = e.srcEvent;
      }
      if (e.offsetX) {
        x = e.offsetX;
        y = e.offsetY;
      } else {
        pos = e.target.getBoundingClientRect();
        x = e.x - pos.left;
        y = e.y - pos.top;
      }
      size = Math.max(this.$el.offsetWidth - x, this.$el.offsetHeight - y, x, y) * 3;
      rippleDiv = this.$els.rippleDiv.cloneNode(true);
      this.setCss(rippleDiv, "top", y + "px");
      this.setCss(rippleDiv, "left", x + "px");
      this.$el.appendChild(rippleDiv);
      duration = size / this.speed / 0.35;
      rippleEl = rippleDiv.firstChild;
      Velocity(rippleEl, {
        opacity: 0.5
      }, {
        duration: duration * 1 / 2,
        queue: false
      });
      Velocity(rippleEl, {
        width: size,
        height: size
      }, {
        duration: duration,
        easing: "easeIn",
        queue: false
      });
      if (isTouch) {
        return setTimeout(((function(_this) {
          return function() {
            return _this.hide({
              rippleDiv: rippleDiv,
              duration: duration * 1 / 2
            });
          };
        })(this)), duration * 1 / 2);
      } else {
        ripple = {
          rippleDiv: rippleDiv,
          duration: duration * 1 / 2,
          released: false,
          timeouted: false
        };
        this.ripples.push(ripple);
        return setTimeout(((function(_this) {
          return function() {
            ripple.timeouted = true;
            if (ripple.released) {
              return _this.hide(ripple);
            }
          };
        })(this)), duration * 1 / 2);
      }
    },
    hide: function(ripple) {
      return Velocity(ripple.rippleDiv.firstChild, {
        opacity: 0
      }, {
        duration: ripple.duration,
        complete: (function(_this) {
          return function() {
            ripple.rippleDiv.remove();
            return _this.ripples.splice(_this.ripples.indexOf(ripple), 1);
          };
        })(this)
      });
    },
    release: function() {
      var lastRipple;
      lastRipple = this.ripples[this.ripples.length - 1];
      if (lastRipple != null) {
        lastRipple.released = true;
        if (lastRipple.timeouted) {
          return this.hide(lastRipple);
        }
      }
    }
  },
  ready: function() {
    return this.getId = GradientStore(this.Vue).getId;
  }
};

if (module.exports.__esModule) module.exports = module.exports.default
;(typeof module.exports === "function"? module.exports.options: module.exports).template = "<div v-bind:style=\"{position:'relative',overflow:'hidden',display:'inline-block',touchAction:'auto'}\" v-touch:tap=show @mouseup=release @mousedown=show><div style=position:absolute;pointer-events:none;transform:translate(-50%,-50%);border-radius:50%;line-height:0 v-el:ripple-div=v-el:ripple-div><svg xmlns=http://www.w3.org/2000/svg height=10 width=10 style=position:relative;opacity:0;pointer-events:none><rect x=0 y=0 width=100% height=100% v-bind:fill=gradUrl></rect></svg></div><slot></slot></div>"
